@@ -18,7 +18,7 @@ from neutron_lib.db import model_base
 import sqlalchemy as sa
 from sqlalchemy import orm
 
-from neutron.db import l3_db
+from neutron.db.models import l3
 from neutron.db import models_v2
 
 from neutron_vpnaas.services.vpn.common import constants
@@ -75,7 +75,7 @@ class IKEPolicy(model_base.BASEV2, model_base.HasId, model_base.HasProject):
                                              "aes-256", "aes-192",
                                              name="vpn_encrypt_algorithms"),
                                      nullable=False)
-    phase1_negotiation_mode = sa.Column(sa.Enum("main",
+    phase1_negotiation_mode = sa.Column(sa.Enum("main", 'aggressive',
                                                 name="ike_phase1_mode"),
                                         nullable=False)
     lifetime_units = sa.Column(sa.Enum("seconds", "kilobytes",
@@ -149,11 +149,13 @@ class VPNService(model_base.BASEV2, model_base.HasId, model_base.HasProject):
     router_id = sa.Column(sa.String(36), sa.ForeignKey('routers.id'),
                           nullable=False)
     subnet = orm.relationship(models_v2.Subnet)
-    router = orm.relationship(l3_db.Router)
+    router = orm.relationship(l3.Router)
     ipsec_site_connections = orm.relationship(
         IPsecSiteConnection,
         backref='vpnservice',
         cascade="all, delete-orphan")
+    flavor_id = sa.Column(sa.String(36), sa.ForeignKey(
+        'flavors.id', name='fk_vpnservices_flavors_id'))
 
 
 class VPNEndpoint(model_base.BASEV2):
@@ -178,7 +180,7 @@ class VPNEndpointGroup(model_base.BASEV2, model_base.HasId,
     name = sa.Column(sa.String(db_const.NAME_FIELD_SIZE))
     description = sa.Column(sa.String(db_const.DESCRIPTION_FIELD_SIZE))
     endpoint_type = sa.Column(sa.Enum(*constants.VPN_SUPPORTED_ENDPOINT_TYPES,
-                                      name="vpn_endpoint_type"),
+                                      name="endpoint_type"),
                               nullable=False)
     endpoints = orm.relationship(VPNEndpoint,
                                  backref='endpoint_group',
