@@ -15,6 +15,7 @@
 from unittest import mock
 
 from neutron.api import extensions
+from neutron.api import wsgi
 from neutron.common.ovn import constants as ovn_constants
 from neutron import policy
 from neutron.tests.common import helpers
@@ -22,7 +23,6 @@ from neutron.tests.unit.api import test_extensions
 from neutron.tests.unit.db import test_db_base_plugin_v2 as test_plugin
 from neutron.tests.unit.extensions import test_l3
 from neutron.tests.unit import testlib_api
-from neutron import wsgi
 from neutron_lib import context
 from neutron_lib import exceptions as n_exc
 from neutron_lib.plugins import constants as plugin_constants
